@@ -1,6 +1,6 @@
 package Net::DNS::RR;
 #
-# $Id: RR.pm,v 2.105 2004/02/09 23:28:31 ctriv Exp $
+# $Id: RR.pm 102 2004-08-12 05:16:06Z ctriv $
 #
 use strict;
 use vars qw($VERSION $AUTOLOAD);
@@ -9,7 +9,7 @@ use Carp;
 use Net::DNS;
 use Net::DNS::RR::Unknown;
 
-$VERSION = (qw$Revision: 2.105 $)[1];
+$VERSION = (qw$LastChangedRevision: 102 $)[1];
 
 =head1 NAME
 
@@ -73,6 +73,7 @@ BEGIN {
 		TXT
 		X25
 		OPT
+		SSHFP
 	);
 
 	#  Only load DNSSEC if available
@@ -415,6 +416,9 @@ sub new_from_hash {
 			# documentation
 			return $subclass->new_from_hash($self);
 	    }
+	} elsif ($self->{'type'} =~ /TYPE\d+/) {
+		bless $self, 'Net::DNS::RR::Unknown';
+		return $self;
 	} else {
 	 	bless $self, $class;
 	 	return $self;
@@ -771,7 +775,7 @@ RR objects.
 
 Copyright (c) 1997-2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2003 Chris Reinhardt.
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
