@@ -1,20 +1,20 @@
 package Net::DNS::Resolver;
 #
-# $Id: Resolver.pm,v 2.101 2004/02/17 05:21:03 ctriv Exp $
+# $Id: Resolver.pm 102 2004-08-12 05:16:06Z ctriv $
 #
 
 use strict;
 use vars qw($VERSION @ISA);
 
-$VERSION = (qw$Revision: 2.101 $)[1];
+$VERSION = (qw$LastChangedRevision: 102 $)[1];
 
 BEGIN {
 	if ($^O eq 'MSWin32') {
 		require Net::DNS::Resolver::Win32;
 		@ISA = qw(Net::DNS::Resolver::Win32);
 	} elsif ($^O eq 'cygwin') {
-		 require Net::DNS::Resolver::Cygwin;
-		 @ISA = qw(Net::DNS::Resolver::Cygwin);
+		require Net::DNS::Resolver::Cygwin;
+		@ISA = qw(Net::DNS::Resolver::Cygwin);
 	} else {   
 		require Net::DNS::Resolver::UNIX;
 		@ISA = qw(Net::DNS::Resolver::UNIX);
@@ -174,58 +174,6 @@ An array reference of domains.
 For more information on any of these options, please consult the method
 of the same name.
 
-=head2 print
-
-    $res->print;
-
-Prints the resolver state on the standard output.
-
-=head2 string
-
-    print $res->string;
-
-Returns a string representation of the resolver state.
-
-=head2 searchlist
-
-    @searchlist = $res->searchlist;
-    $res->searchlist('example.com', 'a.example.com', 'b.example.com');
-
-Gets or sets the resolver search list.
-
-=head2 nameservers
-
-    @nameservers = $res->nameservers;
-    $res->nameservers('192.168.1.1', '192.168.2.2', '192.168.3.3');
-
-Gets or sets the nameservers to be queried.
-
-=head2 port
-
-    print 'sending queries to port ', $res->port, "\n";
-    $res->port(9732);
-
-Gets or sets the port to which we send queries.  This can be useful
-for testing a nameserver running on a non-standard port.  The
-default is port 53.
-
-=head2 srcport
-
-    print 'sending queries from port ', $res->srcport, "\n";
-    $res->srcport(5353);
-
-Gets or sets the port from which we send queries.  The default is 0,
-meaning any port.
-
-=head2 srcaddr
-
-    print 'sending queries from address ', $res->srcaddr, "\n";
-    $res->srcaddr('192.168.1.1');
-
-Gets or sets the source address from which we send queries.  Convenient
-for forcing queries out a specific interfaces on a multi-homed host.
-The default is 0.0.0.0, meaning any local address.
-
 =head2 search
 
     $packet = $res->search('mailhost');
@@ -259,8 +207,9 @@ The record type and class can be omitted; they default to A and
 IN.  If the name looks like an IP address (4 dot-separated numbers),
 then an appropriate PTR query will be performed.
 
-Returns a C<Net::DNS::Packet> object, or C<undef> if no answers
-were found.
+Returns a "Net::DNS::Packet" object, or "undef" if no answers were
+found.  If you need to examine the response packet whether it contains
+any answers or not, use the send() method instead.
 
 =head2 query
 
@@ -275,11 +224,12 @@ applied.  If the name doesn't contain any dots and B<defnames>
 is true then the default domain will be appended.
 
 The record type and class can be omitted; they default to A and
-IN.  If the name looks like an IP address (4 dot-separated numbers),
+IN.  If the name looks like an IP address (IPv4 or IPv6),
 then an appropriate PTR query will be performed.
 
-Returns a C<Net::DNS::Packet> object, or C<undef> if no answers
-were found.
+Returns a "Net::DNS::Packet" object, or "undef" if no answers were
+found.  If you need to examine the response packet whether it contains
+any answers or not, use the send() method instead.
 
 =head2 send
 
@@ -293,7 +243,7 @@ nor the default domain will be appended.
 
 The argument list can be either a C<Net::DNS::Packet> object or a list
 of strings.  The record type and class can be omitted; they default to
-A and IN.  If the name looks like an IP address (4 dot-separated numbers),
+A and IN.  If the name looks like an IP address (Ipv4 or IPv6),
 then an appropriate PTR query will be performed.
 
 Returns a C<Net::DNS::Packet> object whether there were any answers or not.
@@ -301,55 +251,6 @@ Use C<< $packet->header->ancount >> or C<< $packet->answer >> to find out
 if there were any records in the answer section.  Returns C<undef> if there
 was an error.
 
-=head2 bgsend
-
-    $socket = $res->bgsend($packet_object);
-    $socket = $res->bgsend('mailhost.example.com');
-    $socket = $res->bgsend('example.com', 'MX');
-    $socket = $res->bgsend('user.passwd.example.com', 'TXT', 'HS');
-
-Performs a background DNS query for the given name, i.e., sends a
-query packet to the first nameserver listed in C<< $res->nameservers >>
-and returns immediately without waiting for a response.  The program
-can then perform other tasks while waiting for a response from the 
-nameserver.
-
-The argument list can be either a C<Net::DNS::Packet> object or a list
-of strings.  The record type and class can be omitted; they default to
-A and IN.  If the name looks like an IP address (4 dot-separated numbers),
-then an appropriate PTR query will be performed.
-
-Returns an C<IO::Socket::INET> object.  The program must determine when
-the socket is ready for reading and call C<< $res->bgread >> to get
-the response packet.  You can use C<< $res->bgisready >> or C<IO::Select>
-to find out if the socket is ready before reading it.
-
-=head2 bgread
-
-    $packet = $res->bgread($socket);
-    undef $socket;
-
-Reads the answer from a background query (see L</bgsend>).  The argument
-is an C<IO::Socket> object returned by C<bgsend>.
-
-Returns a C<Net::DNS::Packet> object or C<undef> on error.
-
-The programmer should close or destroy the socket object after reading it.
-
-=head2 bgisready
-
-    $socket = $res->bgsend('foo.example.com');
-    until ($res->bgisready($socket)) {
-        # do some other processing
-    }
-    $packet = $res->bgread($socket);
-    $socket = undef;
-
-Determines whether a socket is ready for reading.  The argument is
-an C<IO::Socket> object returned by C<< $res->bgsend >>.
-
-Returns true if the socket is ready, false if not.
-
 =head2 axfr
 
     @zone = $res->axfr;
@@ -414,6 +315,107 @@ SOA record that terminates the zone transfer is not returned.
 
 See also L</axfr>.
 
+=head2 nameservers
+
+    @nameservers = $res->nameservers;
+    $res->nameservers('192.168.1.1', '192.168.2.2', '192.168.3.3');
+
+Gets or sets the nameservers to be queried.
+
+=head2 print
+
+    $res->print;
+
+Prints the resolver state on the standard output.
+
+=head2 string
+
+    print $res->string;
+
+Returns a string representation of the resolver state.
+
+=head2 searchlist
+
+    @searchlist = $res->searchlist;
+    $res->searchlist('example.com', 'a.example.com', 'b.example.com');
+
+Gets or sets the resolver search list.
+
+=head2 port
+
+    print 'sending queries to port ', $res->port, "\n";
+    $res->port(9732);
+
+Gets or sets the port to which we send queries.  This can be useful
+for testing a nameserver running on a non-standard port.  The
+default is port 53.
+
+=head2 srcport
+
+    print 'sending queries from port ', $res->srcport, "\n";
+    $res->srcport(5353);
+
+Gets or sets the port from which we send queries.  The default is 0,
+meaning any port.
+
+=head2 srcaddr
+
+    print 'sending queries from address ', $res->srcaddr, "\n";
+    $res->srcaddr('192.168.1.1');
+
+Gets or sets the source address from which we send queries.  Convenient
+for forcing queries out a specific interfaces on a multi-homed host.
+The default is 0.0.0.0, meaning any local address.
+
+=head2 bgsend
+
+    $socket = $res->bgsend($packet_object);
+    $socket = $res->bgsend('mailhost.example.com');
+    $socket = $res->bgsend('example.com', 'MX');
+    $socket = $res->bgsend('user.passwd.example.com', 'TXT', 'HS');
+
+Performs a background DNS query for the given name, i.e., sends a
+query packet to the first nameserver listed in C<< $res->nameservers >>
+and returns immediately without waiting for a response.  The program
+can then perform other tasks while waiting for a response from the 
+nameserver.
+
+The argument list can be either a C<Net::DNS::Packet> object or a list
+of strings.  The record type and class can be omitted; they default to
+A and IN.  If the name looks like an IP address (4 dot-separated numbers),
+then an appropriate PTR query will be performed.
+
+Returns an C<IO::Socket::INET> object.  The program must determine when
+the socket is ready for reading and call C<< $res->bgread >> to get
+the response packet.  You can use C<< $res->bgisready >> or C<IO::Select>
+to find out if the socket is ready before reading it.
+
+=head2 bgread
+
+    $packet = $res->bgread($socket);
+    undef $socket;
+
+Reads the answer from a background query (see L</bgsend>).  The argument
+is an C<IO::Socket> object returned by C<bgsend>.
+
+Returns a C<Net::DNS::Packet> object or C<undef> on error.
+
+The programmer should close or destroy the socket object after reading it.
+
+=head2 bgisready
+
+    $socket = $res->bgsend('foo.example.com');
+    until ($res->bgisready($socket)) {
+        # do some other processing
+    }
+    $packet = $res->bgread($socket);
+    $socket = undef;
+
+Determines whether a socket is ready for reading.  The argument is
+an C<IO::Socket> object returned by C<< $res->bgsend >>.
+
+Returns true if the socket is ready, false if not.
+
 =head2 tsig
 
     my $tsig = $res->tsig;
@@ -596,10 +598,10 @@ to 1.
     $res->udppacketsize(2048);
 
 udppacketsize will set or get the packet size. If set to a value greater than 
-&Net::DNS::PACKETSZ an EDNS extension will be added indicating suppport for MTU path 
+Net::DNS::PACKETSZ() an EDNS extension will be added indicating suppport for MTU path 
 recovery.
 
-Default udppacketsize is &Net::DNS::PACKETSZ (512)
+Default udppacketsize is Net::DNS::PACKETSZ() (512)
 
 =head1 CUSTOMIZING
 
@@ -682,7 +684,7 @@ No validation of server replies is performed.
 
 Copyright (c) 1997-2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2003 Chris Reinhardt.
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
